@@ -9,7 +9,7 @@ use base qw( Exporter );
 our @EXPORT = qw( find_lib assert_lib check_lib check_lib_or_exit find_lib_or_exit find_lib_or_die );
 
 # ABSTRACT: Check that a library is available for FFI
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 
 our $system_path;
@@ -66,6 +66,12 @@ sub find_lib
   undef $diagnostic;
   croak "find_lib requires lib argument" unless defined $args{lib};
 
+  # _r is an undocumented option to recurively scan sub directories
+  # in attempt to help Alien::Base based FFI modules deal with blib
+  # installs.  It may be removed or altered in a future version without
+  # notice.
+  my $recursive = $args{_r} || 0;
+
   # make arguments be lists.
   foreach my $arg (qw( lib libpath symbol verify ))
   {
@@ -80,9 +86,12 @@ sub find_lib
     }
   }
   
+  my @libpath = @{ $args{libpath} };
+  @libpath = map { _recurse($_) } @libpath if $recursive;
+  
   my %missing = map { $_ => 1 } @{ $args{lib} };
   my %symbols = map { $_ => 1 } @{ $args{symbol} };
-  my @path = (@{ $args{libpath} }, (grep { defined } @$system_path));
+  my @path = (@libpath, (grep { defined } @$system_path));
   my @found;
 
   foreach my $path (@path)
@@ -156,6 +165,17 @@ sub find_lib
   return @found;
 }
 
+sub _recurse
+{
+  my($dir) = @_;
+  return unless -d $dir;
+  my $dh;
+  opendir $dh, $dir;
+  my @list = grep { -d $_ } map { File::Spec->catdir($dir, $_) } grep !/^\.\.?$/, readdir $dh;
+  closedir $dh;
+  ($dir, map { _recurse($_) } @list);
+}
+
 
 sub assert_lib
 {
@@ -217,7 +237,7 @@ FFI::CheckLib - Check that a library is available for FFI
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
